# Faas Supervisor

[![Test, build and deploy](https://github.com/grycap/faas-supervisor/workflows/Test,%20build%20and%20deploy/badge.svg)](https://github.com/grycap/faas-supervisor/actions?query=workflow%3A%22Test%2C+build+and+deploy%22)
[![PyPi version](https://img.shields.io/pypi/v/faas-supervisor.svg)](https://pypi.org/project/faas-supervisor/)
[![License](https://img.shields.io/badge/license-Apache%202-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/b5b3e19aa9ed4ce7accfa54e79163e35)](https://www.codacy.com/gh/grycap/faas-supervisor/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=grycap/faas-supervisor&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/b5b3e19aa9ed4ce7accfa54e79163e35)](https://www.codacy.com/gh/grycap/faas-supervisor/dashboard?utm_source=github.com&utm_medium=referral&utm_content=grycap/faas-supervisor&utm_campaign=Badge_Coverage)

Input / Output data manager for FaaS functions.
Works in different cloud environments and allows different data providers.

Python package available at Pypi with the name **faas-supervisor**.
